# 🤝 Contributing to the Structural Bioinformatics Tool Collection

We welcome contributions from all members of the group!  
This guide explains how to add or edit tools and topics in the `README.md`.

---

## ✅ How to Add or Edit a Tool

1. **Fork** the repository or **clone it and create a new branch**:
   ```bash
   git clone https://gitlab.rpbs.univ-paris-diderot.fr/rpbs/collection-tools.git
   cd collection-tools
   git checkout -b add-my-tool
   ```

2. Edit README.md

    - Identify the correct topic section.
    - Insert your tool at the top of the list (sorted by date, most recent first).
    - Use the following markdown format:

    ```markdown
    ### [Tool Name](https://github.com/your/tool) – *Month YYYY*

    **Description:** A short summary of the tool and what it does.

    **Paper:** [Journal Name](https://link-to-paper)

    **Code:** [GitHub – toolname](https://github.com/your/tool)

    **Web Server:** [toolname.org](https://toolname.org) *(optional)*

    **Licence:** MIT

    **Tags:** #example #bioinformatics #open-source
    ```

3. Commit and push your changes:
   ```bash
    git commit -am "Add ToolName under [Topic]"
    git push origin add-my-tool
   ```

4. Create a Merge Request (MR)](https://docs.gitlab.com/user/project/merge_requests/creating_merge_requests/#from-the-merge-request-list) via the GitLab web interface:

    - Go to your branch on GitLab
    - Click "Create merge request"
    - Add a short title and description


## 🆕 How to Add a New Topic

1. Open the README.md file and scroll to the Topics section.
2. Add your new topic to the list with a link to its section.
3. Create a new section below using the following format:

    ```markdown
    ## New Topic Name

    > A short description of what types of tools fit into this category.

    ### [Tool Name](https://link) – *Month YYYY*

    **Description:** Brief overview of what the tool does.

    **Paper:** [Journal Name](https://doi.org/link)

    **Code:** [GitHub](https://github.com/tool)

    **Web Server:** [toolsite.org](https://toolsite.org) *(optional)*

    **Tags:** #example #new-topic
    ```


4. Commit and push your changes:
   ```bash
    git commit -am "Add ToolName under [Topic]"
    git push origin add-my-tool
   ```

5. Create a [Merge Request (MR)](https://docs.gitlab.com/user/project/merge_requests/creating_merge_requests/#from-the-merge-request-list) via the GitLab web interface:

    - Go to your branch on GitLab
    - Click "Create merge request"
    - Add a short title and description

    
