
# 🧬 Structural Bioinformatics Tool Collection

This page aims at being a curated and collaborative list of tools and resources relevant to our research group's topics of interest.  
Tools must be accessible either through a GitHub repository or a web server.

This page aims to:

- 📌 Centralize useful tools for quick reference  
- 🚀 Help researchers stay updated with the latest methods  
- 🤝 Encourage sharing of tools across the team  
- 🛠️ Provide a living resource that evolves with the field

---

## 📚 Topics

Tools are grouped by **research topic**. Within each topic, tools are listed in **reverse chronological order** (most recent first).

Current topics include:

- [Biomolecular Interaction Prediction](#biomolecular-interaction-prediction)
- [Ligand Binding and Docking](#ligand-binding-and-docking)
- [Molecular Design](#molecular-design)
- [Molecular Dynamics and Simulations](#molecular-dynamics-and-simulations)
- [Other Tool Collections](#other-tool-collections)
- [Miscellaneous](#miscellaneous)

---

## ➕ How to Contribute

We welcome contributions from all members of the group! 

You can expand this collection: by following [contribution guideline](./CONTRIBUTING.md).


## 🧪 Tool Listings

---
<br>

## Biomolecular Interaction Prediction
[Go to topics](#-topics)


> Tools for predicting or modeling interactions between proteins, peptides, nucleic acids, and other biomolecules. Includes methods for PPI, protein–peptide, and nucleic acid interactions.

### [SpatialPPI-2.0](https://github.com/ohuelab/SpatialPPIv2) – *January 2025*

**Description:** SpatialPPI-2.0 is an advanced graph-neural-network-based model that predicts PPIs by using large language models to embed sequence features and Graph Attention Networks to capture structural information.

**Paper:** [Computational and Structural Biotechnology Journal](https://www.sciencedirect.com/science/article/pii/S2001037025000224)

**Code:** [GitHub - SpatialPPI](https://github.com/ohuelab/SpatialPPIv2)

**Licence:** Apache-2.0 license 

**Tags:** #deep-learning #PPI #open-source #interaction-propensity #graph-attention

---

### [FragFold](https://github.com/swanss/FragFold) – *December 2024*

**Description:** FragFold implements a custom protocol to run alphafold to predict "how short fragments of natural proteins bind to full-length proteins".

**Paper:** [PNAS](https://www.pnas.org/doi/10.1073/pnas.2322412122)

**Code:** [GitHub – FragFold](https://github.com/swanss/FragFold)

**Licence:** MIT

**Tags:** #inhibitory-peptides #protein-interactions #in-silico-pepscan #open-source

---

<br>

## Ligand Binding and Docking
[Go to topics](#-topics)


> Tools focused on predicting, modeling, or simulating the binding of small molecules (ligands) to macromolecules, including docking software and scoring methods.

### [DynamicBind](https://github.com/luwei0917/DynamicBind) – *January 2024*

**Description:** DynamicBind recovers ligand-specific conformations from unbound protein structures (e.g. AF2-predicted structures), promoting efficient transitions between different equilibrium states.

**Paper:** [Nature com.](https://www.nature.com/articles/s41467-024-45461-2)

**Code:** [GitHub – DynamicBind](https://github.com/luwei0917/DynamicBind)

**Licence:** MIT

**Tags:** #ligand-binding #conformations #ai #open-source #diffusion #state-transition

---

### [GNINA](https://github.com/gnina/gnina) – *June 2021*

**Description:** Molecular docking software with integrated convolutional neural networks for scoring protein–ligand binding.

**Paper:** [Journal of Cheminformatics](https://jcheminf.biomedcentral.com/articles/10.1186/s13321-021-00522-2)

**Code:** [GitHub – GNINA](https://github.com/gnina/gnina)

**Licence:** Apache-2.0, GPL-2.0  

**Tags:** #docking #CNN #ligand-binding #GPU #chemoinformatics #drug-discovery #open-source

---

<br>

## Molecular Design
[Go to topics](#-topics)


> Tools for designing new protein, peptide, or ligand sequences and structures. Includes sequence optimization, scaffold design, and generative models.

### [ProteinMPNN](https://github.com/dauparas/ProteinMPNN) – *September 2022*

**Description:** A fast and flexible backbone-conditioned protein sequence design method using deep learning.

**Paper:** [Science](https://www.science.org/doi/10.1126/science.add2187)

**Code:** [GitHub – ProteinMPNN](https://github.com/dauparas/ProteinMPNN)

**Licence:** MIT

**Tags:** #design #sequence-generation #deep-learning #open-source

---

<br>

## Molecular Dynamics and Simulations
[Go to topics](#-topics)


> Molecular simulation engines and related tools for modeling dynamic behavior of molecules over time. Includes force fields, enhanced sampling, and coarse-grain models.

### [OpenMM](https://github.com/openmm/openmm) – *January 2024*

**Description:** High-performance toolkit for molecular dynamics simulations, supporting GPU acceleration and Python scripting.

**Paper:** [Journal of Physics & Chemistry](https://doi.org/10.1021/acs.jpcb.3c06662)

**Code:** [GitHub – OpenMM](https://github.com/openmm/openmm)

**Licence:** ???

**Tags:** #MD #GPU #python #open-source #pytorch #cuda

---

<br>

## Other Tool Collections
[Go to topics](#-topics)


> Curated collections of tools, datasets, and papers around a specific topic. Useful for deep dives and meta-resources.

### [Papers for Protein Design Using DL](https://github.com/Peldom/papers_for_protein_design_using_DL) – *August 2023*

**Description:** A curated list of deep learning papers and tools related to protein design.

**Paper:** None

**Code:** [GitHub – Peldom Collection](https://github.com/Peldom/papers_for_protein_design_using_DL)

**Licence:** GPL-3.0 license 

**Tags:** #collection #design #dataset #tools #papers

---

<br>

## Miscellaneous
[Go to topics](#-topics)


> Tools that don’t yet fit cleanly into another category, such as visualization, file conversion, or general-purpose bioinformatics software.

### [Mol* Viewer](https://github.com/molstar/molstar) – *September 2022*

**Description:** Web-based molecular visualization tool used by RCSB PDB and others, supporting interactive structure exploration.

**Paper:** [Nature Methods](https://doi.org/10.1038/s41592-020-01056-5)

**Code:** [GitHub – Mol\*](https://github.com/molstar/molstar)

**Web Server:** [https://molstar.org/viewer/](https://molstar.org/viewer/)

**Tags:** #visualization #webapp #structure-viewer

---
<br>


## 🙌 Maintainers

This repository is maintained by the **RPBS platform**. If you have questions or ideas, feel free to open an issue or reach out directly.

---
<br>


## 📄 License

This content is released under the MIT License.
